@@ -11,7 +11,7 @@ use KinoSearch::Search::HitCollector::BitCollector;
 use Data::Dump qw( dump );
 use Scalar::Util qw( blessed );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub init_searcher {
     my $self     = shift;
@@ -27,17 +27,19 @@ sub build_facets {
     my $self    = shift;
     my $query   = shift or croak "query required";
     my $results = shift or croak "results required";
-    $self->logger
-        and $self->logger->log(
-        "build_facets check for self->facets=" . $self->facets );
+    if ( $self->debug and $self->logger ) {
+        $self->logger->log(
+            "build_facets check for self->facets=" . $self->facets );
+    }
     my $facetobj = $self->facets or return;
 
     my @facet_names = @{ $facetobj->names };
     my $sample_size = $facetobj->sample_size || 0;
-    $self->logger
-        and $self->logger->log( "building facets for "
-            . dump( \@facet_names )
-            . " with sample_size=$sample_size" );
+    if ( $self->debug and $self->logger ) {
+        $self->logger->log( "building facets for "
+                . dump( \@facet_names )
+                . " with sample_size=$sample_size" );
+    }
     my $searcher     = $self->searcher;
     my $ks_searcher  = $searcher->{ks};
     my $query_parser = $searcher->{qp};
@@ -74,9 +76,10 @@ sub build_facets {
         }
     }
 
-    $self->logger
-        and $self->logger->log(
-        "got " . scalar( keys %facets ) . " facets in $loops loops" );
+    if ( $self->debug and $self->logger ) {
+        $self->logger->log(
+            "got " . scalar( keys %facets ) . " facets in $loops loops" );
+    }
 
     # turn the struct inside out a bit, esp for XML
     my %facet_struct;
